@@ -10,14 +10,15 @@ class NeverGradAlgoWrapper():
     def __init__(self):
         self.algorithm = None
         self.default_method = 'RandomSearch'
+        self.default_budget = 100
 
     def create(self, metric, mode, search_space, **args):
         search_space = NeverGradSpace(search_space).get_search_space()
         if ('method' in args) and (args['method']):
             method = args['method']
         else:
-            method = default_method
+            method = self.default_method
         optimizer = ng.optimizers.registry[method](
-                parametrization=search_space, budget=default_budget)
+                parametrization=search_space, budget=self.default_budget)
         self.algorithm = NevergradSearch(optimizer, None, metric=metric, mode=mode, **args)
         return self.algorithm
\ No newline at end of file
