@@ -50,11 +50,12 @@ class GridHandler():
                  'useSandbox': '',
                  'noBuild': ''}
                  
-#        extra['alrb'] = ''
+        extra['alrb'] = ''
 
         options.update(extra)
-        options['ctrWorkdir'] = kWorkDir
-        options['ctrDatadir'] = kDataDir
+        # no longer valid with alrb
+#        options['ctrWorkdir'] = kWorkDir
+#        options['ctrDatadir'] = kDataDir
 
         if grid_config['inDS']:
             options['inDS'] = grid_config['inDS']
