@@ -326,7 +326,8 @@ class JobBuilder():
         # save idds output
         if self.idds_job:
             idds_output = self.create_idds_output(metadata)
-            idds_output_path = os.path.join(kWorkDir,kiDDSHPoutput)
+            workdir = helper.get_workdir()
+            idds_output_path = os.path.join(workdir,kiDDSHPoutput)
             with open(idds_output_path, 'w') as idds_output_file:
                 json.dump(idds_output, idds_output_file, cls=helper.NpEncoder)
 
@@ -339,7 +340,8 @@ class JobBuilder():
         helper.set_script_path(proj_name)
         
         if idds_job:
-            input_point_path = os.path.join(kWorkDir, kiDDSHPinput)
+            workdir = helper.get_workdir()
+            input_point_path = os.path.join(workdir, kiDDSHPinput)
             with open(input_point_path,'r') as input_point_file:
                 input_point = json.load(input_point_file)
             return JobBuilder.from_config_for_idds(config, input_point)
@@ -430,15 +432,17 @@ def local_job_parser(idds_job=False):
     parser.add_argument('proj_name', help='Name of the project on which '
                         'hyperparameter optimization is run')    
     args = parser.parse_args(sys.argv[2:])
-
+    
+    helper.local_setup()
     job = JobBuilder.from_project(args.proj_name, idds_job=idds_job)
     job.run()
             
 def grid_job_parser(idds_job=False):
     extracted_files = []
     try:
-        extracted_files = helper.extract_tarball(kDataDir, kDataDir)
         helper.grid_site_setup()
+        datadir = helper.get_datadir()
+        extracted_files = helper.extract_tarball(datadir, datadir)
         local_job_parser(idds_job=idds_job)
     finally:
         helper.remove_files(extracted_files)
