@@ -7,13 +7,14 @@ _help_test = 'test'
 
 kDefaultDisk = 'UKI-NORTHGRID-MAN-HEP_SCRATCHDISK'
 kDefaultDatasetName = 'user.${RUCIO_ACCOUNT}.hpo.test01.dataset'
+kDefaultTempDir = './'
 
 def get_rucio_parser():
 	
 	parser = argparse.ArgumentParser()
 	parser.add_argument('data_paths', nargs='+', help=_help_test)
 	parser.add_argument('-n', '--name', help=_help_test, default=kDefaultDatasetName)
-	parser.add_argument('-t', '--temp_dir', help=_help_test)
+	parser.add_argument('-t', '--temp_dir', help=_help_test, default=kDefaultTempDir)
 	parser.add_argument('-d','--disk', help=_help_test, default=kDefaultDisk)
 	parser.add_argument('-s', '--save', action='store_true', help=_help_test, default=False)
 
@@ -37,3 +38,7 @@ def make_tarfile(source, outname):
     	for src in source:
         	tar.add(src, arcname=os.path.basename(src))
 
+if __name__ == '__main__':
+	parser = get_rucio_parser()
+	args = parser.parse_args()
+	upload_rucio(args)
